@@ -13,7 +13,7 @@ use oauth10a::client::{ClientError, RestClient};
 use schemars::JsonSchema;
 use serde::{Deserialize, Serialize};
 
-use crate::Client;
+use crate::{v4::addon_provider::config_provider::addon::environment::Variable, Client};
 
 // -----------------------------------------------------------------------------
 // Provider structure
@@ -116,23 +116,25 @@ pub struct Addon {
 }
 
 // -----------------------------------------------------------------------------
-// AddonOpts enum
+// Opts enum
 
 #[cfg_attr(feature = "jsonschemas", derive(JsonSchema))]
 #[derive(Serialize, Deserialize, Eq, PartialEq, PartialOrd, Ord, Clone, Debug, Default)]
-pub struct AddonOpts {
+pub struct Opts {
     #[serde(rename = "version", skip_serializing_if = "Option::is_none")]
     pub version: Option<String>,
     #[serde(rename = "encryption", skip_serializing_if = "Option::is_none")]
     pub encryption: Option<String>,
+    #[serde(rename = "services", skip_serializing_if = "Option::is_none")]
+    pub services: Option<String>,
 }
 
 // -----------------------------------------------------------------------------
-// CreateAddonOpts structure
+// CreateOpts structure
 
 #[cfg_attr(feature = "jsonschemas", derive(JsonSchema))]
 #[derive(Serialize, Deserialize, PartialEq, PartialOrd, Clone, Debug)]
-pub struct CreateAddonOpts {
+pub struct CreateOpts {
     #[serde(rename = "name")]
     pub name: String,
     #[serde(rename = "region")]
@@ -142,19 +144,7 @@ pub struct CreateAddonOpts {
     #[serde(rename = "plan")]
     pub plan: String,
     #[serde(rename = "options")]
-    pub options: AddonOpts,
-}
-
-// -----------------------------------------------------------------------------
-// EnvironmentVariable struct
-
-#[cfg_attr(feature = "jsonschemas", derive(JsonSchema))]
-#[derive(Serialize, Deserialize, PartialEq, PartialOrd, Clone, Debug)]
-pub struct EnvironmentVariable {
-    #[serde(rename = "name")]
-    pub name: String,
-    #[serde(rename = "value")]
-    pub value: String,
+    pub options: Opts,
 }
 
 // -----------------------------------------------------------------------------
@@ -167,7 +157,7 @@ pub enum Error {
     #[error("failed to get addon '{0}' of organisation '{1}', {2}")]
     Get(String, String, ClientError),
     #[error("failed to get addon '{0}' environment of organisation '{1}', {2}")]
-    GetEnvironment(String, String, ClientError),
+    Environment(String, String, ClientError),
     #[error("failed to create addon for organisation '{0}', {1}")]
     Create(String, ClientError),
     #[error("failed to delete addon '{0}' for organisation '{1}', {2}")]
@@ -229,7 +219,7 @@ where
 pub async fn create<C>(
     client: &Client<C>,
     organisation_id: &str,
-    opts: &CreateAddonOpts,
+    opts: &CreateOpts,
 ) -> Result<Addon, Error>
 where
     C: Connect + Clone + Debug + Send + Sync + 'static,
@@ -298,10 +288,10 @@ where
         );
     }
 
-    let env: Vec<EnvironmentVariable> = client
+    let env: Vec<Variable> = client
         .get(&path)
         .await
-        .map_err(|err| Error::GetEnvironment(id.to_owned(), organisation_id.to_owned(), err))?;
+        .map_err(|err| Error::Environment(id.to_owned(), organisation_id.to_owned(), err))?;
 
     Ok(env.iter().fold(BTreeMap::new(), |mut acc, var| {
         acc.insert(var.name.to_owned(), var.value.to_owned());
