@@ -15,6 +15,8 @@ use std::{
 use schemars::JsonSchema;
 use serde::{Deserialize, Serialize};
 
+pub mod config_provider;
+pub mod elasticsearch;
 pub mod mongodb;
 pub mod mysql;
 pub mod plan;
@@ -91,6 +93,8 @@ pub enum AddonProviderId {
     MySql,
     MongoDb,
     Pulsar,
+    ConfigProvider,
+    ElasticSearch,
 }
 
 impl FromStr for AddonProviderId {
@@ -104,6 +108,8 @@ impl FromStr for AddonProviderId {
             "postgresql-addon" => Self::PostgreSql,
             "mongodb-addon" => Self::MongoDb,
             "addon-pulsar" => Self::Pulsar,
+            "config-provider" => Self::ConfigProvider,
+            "es-addon" => Self::ElasticSearch,
             _ => return Err(Error::Parse(s.to_owned())),
         })
     }
@@ -134,6 +140,8 @@ impl Display for AddonProviderId {
             Self::MySql => write!(f, "mysql-addon"),
             Self::MongoDb => write!(f, "mongodb-addon"),
             Self::Pulsar => write!(f, "addon-pulsar"),
+            Self::ConfigProvider => write!(f, "config-provider"),
+            Self::ElasticSearch => write!(f, "es-addon"),
         }
     }
 }
